<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Arc3P</name>
    <message>
        <location filename="../Arc3P.js" line="+62"/>
        <source>Start point</source>
        <translatorcomment>--google--
Punkt początkowy (y):
Punkt początkowy (y)
Punkt początkowy (x):</translatorcomment>
        <translation>Punkt początkowy</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Point on arc</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punkt na łuku</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End point</source>
        <translatorcomment>--google--
Punkt końcowy (x):
Punkt końcowy (x)
Punkt końcowy (y):</translatorcomment>
        <translation>Punkt końcowy</translation>
    </message>
    <message>
        <location filename="../Arc3PInit.js" line="+2"/>
        <source>&amp;3 Points</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;3 Punkty</translatorcomment>
        <translation>&amp;3 punkty</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 3 points</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje łuk przez 3 punkty</translation>
    </message>
</context>
</TS>
